==> trade-center-api-2.3.75-sources.jar: cn/com/duiba/order/center/api/dto/AmbAlipayPaybackDto.java <==
package cn.com.duiba.order.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * @author yansen
 */
public class AmbAlipayPaybackDto implements Serializable{
	
	
	public static final String AlipayPaybackStatusWait="wait";
	public static final String AlipayPaybackStatusSuccess="success";
	public static final String AlipayPaybackStatusSend = "send";
	public static final String AlipayPaybackStatusFail="fail";
	private static final long serialVersionUID = -2743053867007555071L;

	private Long id;

	private Long orderId;

	private Long ambSubOrderId;

	private Long ambPaychannelOrderId;

	private String orderNum;

	private String tradeNo;

	private Long refundPrice;

	private String status;

	private String reason;

	private String remark;

	private String notifyContent;

	private Date gmtCreate;

	private Date gmtModified;

	private Date payChannelTime;

	public Date getPayChannelTime() {
		return payChannelTime;
	}

	public void setPayChannelTime(Date payChannelTime) {
		this.payChannelTime = payChannelTime;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getOrderId() {
		return orderId;
	}

	public void setOrderId(Long orderId) {
		this.orderId = orderId;
	}

	public Long getAmbSubOrderId() {
		return ambSubOrderId;
	}

	public void setAmbSubOrderId(Long ambSubOrderId) {
		this.ambSubOrderId = ambSubOrderId;
	}

	public Long getAmbPaychannelOrderId() {
		return ambPaychannelOrderId;
	}

	public void setAmbPaychannelOrderId(Long ambPaychannelOrderId) {
		this.ambPaychannelOrderId = ambPaychannelOrderId;
	}

	public String getOrderNum() {
		return orderNum;
	}

	public void setOrderNum(String orderNum) {
		this.orderNum = orderNum;
	}

	public String getTradeNo() {
		return tradeNo;
	}

	public void setTradeNo(String tradeNo) {
		this.tradeNo = tradeNo;
	}

	public Long getRefundPrice() {
		return refundPrice;
	}

	public void setRefundPrice(Long refundPrice) {
		this.refundPrice = refundPrice;
	}

	public String getStatus() {
		return status;
	}

	public void setStatus(String status) {
		this.status = status;
	}

	public String getReason() {
		return reason;
	}

	public void setReason(String reason) {
		this.reason = reason;
	}

	public String getRemark() {
		return remark;
	}

	public void setRemark(String remark) {
		this.remark = remark;
	}

	public String getNotifyContent() {
		return notifyContent;
	}

	public void setNotifyContent(String notifyContent) {
		this.notifyContent = notifyContent;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

}

==> trade-center-api-3.0.14-sources.jar: cn/com/duiba/order/center/api/dto/AmbAlipayPaybackDto.java <==
package cn.com.duiba.order.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * @author yansen
 */
public class AmbAlipayPaybackDto implements Serializable{
	
	
	public static final String AlipayPaybackStatusWait="wait";
	public static final String AlipayPaybackStatusSuccess="success";
	public static final String AlipayPaybackStatusSend = "send";
	public static final String AlipayPaybackStatusFail="fail";
	public static final String AlipayPaybackStatusException="exception";
	private static final long serialVersionUID = -2743053867007555071L;

	private Long id;

	private Long orderId;

	private Long ambSubOrderId;

	private Long ambPaychannelOrderId;

	private String orderNum;

	private String tradeNo;

	private Long refundPrice;

	private String status;

	private String reason;

	private String remark;

	private String notifyContent;

	private Date gmtCreate;

	private Date gmtModified;

	private Date payChannelTime;

	//主订单子订单号
	private Long ordersItemId;

	public Date getPayChannelTime() {
		return payChannelTime;
	}

	public void setPayChannelTime(Date payChannelTime) {
		this.payChannelTime = payChannelTime;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getOrderId() {
		return orderId;
	}

	public void setOrderId(Long orderId) {
		this.orderId = orderId;
	}

	public Long getAmbSubOrderId() {
		return ambSubOrderId;
	}

	public void setAmbSubOrderId(Long ambSubOrderId) {
		this.ambSubOrderId = ambSubOrderId;
	}

	public Long getAmbPaychannelOrderId() {
		return ambPaychannelOrderId;
	}

	public void setAmbPaychannelOrderId(Long ambPaychannelOrderId) {
		this.ambPaychannelOrderId = ambPaychannelOrderId;
	}

	public String getOrderNum() {
		return orderNum;
	}

	public void setOrderNum(String orderNum) {
		this.orderNum = orderNum;
	}

	public String getTradeNo() {
		return tradeNo;
	}

	public void setTradeNo(String tradeNo) {
		this.tradeNo = tradeNo;
	}

	public Long getRefundPrice() {
		return refundPrice;
	}

	public void setRefundPrice(Long refundPrice) {
		this.refundPrice = refundPrice;
	}

	public String getStatus() {
		return status;
	}

	public void setStatus(String status) {
		this.status = status;
	}

	public String getReason() {
		return reason;
	}

	public void setReason(String reason) {
		this.reason = reason;
	}

	public String getRemark() {
		return remark;
	}

	public void setRemark(String remark) {
		this.remark = remark;
	}

	public String getNotifyContent() {
		return notifyContent;
	}

	public void setNotifyContent(String notifyContent) {
		this.notifyContent = notifyContent;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

	public Long getOrdersItemId() {
		return ordersItemId;
	}

	public void setOrdersItemId(Long ordersItemId) {
		this.ordersItemId = ordersItemId;
	}
}
